#
# spec file for package python-typer-slim
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2021 Matthias Bach <marix@marix.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-typer-slim
Version:        0.15.1
Release:        1.2
Summary:        Typer, build great CLIs. Easy to code. Based on Python type hints
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/tiangolo/typer
Source:         https://files.pythonhosted.org/packages/source/t/typer_slim/typer_slim-%{version}.tar.gz
Source2:        %{name}-rpmlintrc
Patch1:         set-proper-pythonpath-for-tutorial-script-tests.patch
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module pdm-backend}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module rich}
BuildRequires:  %{python_module shellingham}
BuildRequires:  %{python_module typing_extensions}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-click >= 8.0.0
Requires:       python-typing_extensions >= 3.7.4.3
Suggests:       python-rich
Suggests:       python-shellingham
Obsoletes:      python-typer < 0.12.0
BuildArch:      noarch
%python_subpackages

%description
Typer is a library for building CLI applications based on Python 3.7+ type hints.

Based on type hints, Typer enables great editor support and completion for developers.
With automatic help and completion, Typer makes CLIs easy to use for users.

This package provides the Typer Python package required to build and run Typer-based CLI applications.

%prep
%setup -q -n typer_slim-%{version}
%autopatch -p1

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# The typer command is only meant to be provided by the full typer
# package. It's unclear why it shows up here.
%python_expand rm -rf %{buildroot}/%{_bindir}/typer

%check
# the completion tests fail as build runs in sh which is not supported
%pytest -k 'not test_show_completion and not test_install_completion'

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/typer
%{python_sitelib}/typer_slim-%{version}*-info

%changelog
* Wed Dec  4 2024 Matthias Bach <marix@marix.org> - 0.15.1
- Update to 0.15.1
  * Deprecate shell_complete and continue to use autocompletion for
    CLI parameters.
* Tue Dec  3 2024 Matthias Bach <marix@marix.org> - 0.15.0
- Update to 0.15.0
  * Add support for extending typer apps without passing a name,
    add commands to the top level.
  * Breaking change:  Remove auto naming of groups added via
    add_typer based on the group's callback function name.
* Thu Nov 21 2024 Dirk Müller <dmueller@suse.com>
- update to 0.13.1:
  * Remove Rich tags when showing completion text.
  * Render Rich markup as HTML in Markdown docs.
  * Support cp850 encoding for auto-completion in PowerShell.
  * Allow gettext translation of help message.
  * Fix printing HTML from Rich output.
- update to 0.13.0:
  * Handle `KeyboardInterrupt` separately from other
    exceptions.
  * Update `launch` to not print anything when opening urls.
  * Fix equality check for custom classes. PR #979 by @AryazE.
  * Allow colon in zsh autocomplete values and descriptions. PR
  * Deprecate support for `is_flag` and `flag_value`
    parameters.
  * Remove unused functionality from `_typing.py` file.
  * Fix typo in function name `_make_rich_text`.
  * Only run completion installation tests when the env var
    `_TYPER_RUN_INSTALL_COMPLETION_TESTS` is set.
* Fri Sep 27 2024 Matthias Bach <marix@marix.org> - 0.12.5
- Switch PDM dependency from python3-pdm to python3-pdm-backend to
  account for changes in that package's structure.
* Thu Aug 29 2024 Matthias Bach <marix@marix.org> - 0.12.5
- Update to upstream version 0.12.5
  * Unify the width of the Rich console for help and errors.
  * Improve assertion error message if a group is not a valid subclass.
  * Ensure rich_markup_mode=None disables Rich formatting.
* Sat Aug 17 2024 Matthias Bach <marix@marix.org> - 0.12.4
- Update to upstream version 0.12.4
  * Fix support for UnionType (e.g. str | None) with Python 3.11.
  * Fix zsh autocompletion installation.
  * Fix usage of Annotated with future annotations in Python 3.7+.
  * Fix shell_complete not working for Arguments.
* Tue Apr  9 2024 Matthias Bach <marix@marix.org> - 0.12.3
- Update to upstream version 0.12.3
  * Fix Rich formatting with no commands.
  * Improve column help display, ensure commands column width is
    the same on all panels.
  * Add support for an argument of type Optional[Tuple] and default
    value None.
* Sat Apr  6 2024 Matthias Bach <marix@marix.org> - 0.12.1
- Update to upstream version 0.12.1
  * No functional changes, only changes to upstream package
    structure.
* Mon Apr  1 2024 Matthias Bach <marix@marix.org> - 0.12.0
- Provide ustream version 0.12.0
  * Extract core functionality into a separate slim package.
- Add set-proper-pythonpath-for-tutorial-script-tests.patch to fix
  issues with import failures in tests.
